@@ -31,7 +31,7 @@ npm install cdk-aurora-globaldatabase@latest
 npm install cdk-aurora-globaldatabase@cdkv1
 ```
 
-💡💡💡 please click [here](https://github.com/neilkuan/cdk-aurora-globaldatabase/tree/cdkv1#readme), if you are using aws-cdk v1.x.x version.💡💡💡
+# ⛔️ Please do not use cdk v1, because lot of db engine version already not been update in @aws-cdk/aws-rds upstream. ⛔️
 
 ## Now Try It !!!
 
@@ -122,10 +122,10 @@ const globaldbM = new GlobalAuroraRDSMaster(stackM, 'globalAuroraRDSMaster',{
   vpc: vpcPublic,
   rdsPassword: '1qaz2wsx',
   engineVersion: _rds.DatabaseClusterEngine.auroraPostgres({
-    version: _rds.AuroraPostgresEngineVersion.VER_11_7}),
+    version: _rds.AuroraPostgresEngineVersion.VER_12_11}),
   dbClusterpPG: new _rds.ParameterGroup(stackM, 'dbClusterparametergroup', {
     engine: _rds.DatabaseClusterEngine.auroraPostgres({
-      version: _rds.AuroraPostgresEngineVersion.VER_11_7,
+      version: _rds.AuroraPostgresEngineVersion.VER_12_11,
     }),
     parameters: {
       'rds.force_ssl': '1',
@@ -201,6 +201,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -252,6 +254,27 @@ class GlobalAuroraRDSMaster(
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                db_clusterp_pg: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
+                db_user_name: typing.Optional[builtins.str] = None,
+                default_database_name: typing.Optional[builtins.str] = None,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                engine_version: typing.Optional[aws_cdk.aws_rds.IClusterEngine] = None,
+                instance_type: typing.Optional["InstanceTypeEnum"] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                rds_password: typing.Optional[builtins.str] = None,
+                storage_encrypted: typing.Optional[builtins.bool] = None,
+                time_zone: typing.Optional["MySQLtimeZone"] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GlobalAuroraRDSMasterProps(
             db_clusterp_pg=db_clusterp_pg,
             db_user_name=db_user_name,
@@ -275,23 +298,44 @@ class GlobalAuroraRDSMaster(
         id: builtins.str,
         *,
         region: builtins.str,
+        db_parameter_group: typing.Optional[builtins.str] = None,
         db_subnet_group_name: typing.Optional[builtins.str] = None,
+        security_group_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param region: 
+        :param db_parameter_group: 
         :param db_subnet_group_name: 
+        :param security_group_id: 
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                region: builtins.str,
+                db_parameter_group: typing.Optional[builtins.str] = None,
+                db_subnet_group_name: typing.Optional[builtins.str] = None,
+                security_group_id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = RegionalOptions(
-            region=region, db_subnet_group_name=db_subnet_group_name
+            region=region,
+            db_parameter_group=db_parameter_group,
+            db_subnet_group_name=db_subnet_group_name,
+            security_group_id=security_group_id,
         )
 
         return typing.cast(None, jsii.invoke(self, "addRegionalCluster", [scope, id, options]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="clusterEngineVersion")
     def cluster_engine_version(self) -> builtins.str:
         '''(experimental) return RDS Cluster DB Engine Version.
@@ -300,7 +344,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "clusterEngineVersion"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dbClusterpPG")
     def db_clusterp_pg(self) -> aws_cdk.aws_rds.IParameterGroup:
         '''(experimental) return RDS Cluster ParameterGroup.
@@ -309,7 +353,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(aws_cdk.aws_rds.IParameterGroup, jsii.get(self, "dbClusterpPG"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="engine")
     def engine(self) -> builtins.str:
         '''(experimental) return RDS Cluster DB Engine .
@@ -318,7 +362,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "engine"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="engineVersion")
     def engine_version(self) -> aws_cdk.aws_rds.IClusterEngine:
         '''(experimental) return RDS Cluster DB Engine Version.
@@ -327,7 +371,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(aws_cdk.aws_rds.IClusterEngine, jsii.get(self, "engineVersion"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="globalClusterArn")
     def global_cluster_arn(self) -> builtins.str:
         '''(experimental) return Global RDS Cluster Resource ARN .
@@ -336,7 +380,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "globalClusterArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="globalClusterIdentifier")
     def global_cluster_identifier(self) -> builtins.str:
         '''(experimental) return Global RDS Cluster Identifier .
@@ -345,7 +389,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "globalClusterIdentifier"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rdsCluster")
     def rds_cluster(self) -> aws_cdk.aws_rds.DatabaseCluster:
         '''(experimental) return RDS Cluster.
@@ -354,7 +398,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(aws_cdk.aws_rds.DatabaseCluster, jsii.get(self, "rdsCluster"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rdsClusterarn")
     def rds_clusterarn(self) -> builtins.str:
         '''(experimental) return RDS Cluster Resource ARN .
@@ -363,7 +407,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "rdsClusterarn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rdsInstanceType")
     def rds_instance_type(self) -> "InstanceTypeEnum":
         '''(experimental) return Global RDS Cluster instance Type .
@@ -372,7 +416,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast("InstanceTypeEnum", jsii.get(self, "rdsInstanceType"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rdsIsPublic")
     def rds_is_public(self) -> aws_cdk.aws_ec2.SubnetType:
         '''(experimental) return RDS Cluster is Public ?
@@ -381,7 +425,7 @@ class GlobalAuroraRDSMaster(
         '''
         return typing.cast(aws_cdk.aws_ec2.SubnetType, jsii.get(self, "rdsIsPublic"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rdsPassword")
     def rds_password(self) -> typing.Optional[builtins.str]:
         '''(experimental) return RDS Cluster password.
@@ -442,6 +486,34 @@ class GlobalAuroraRDSMasterProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                *,
+                db_clusterp_pg: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
+                db_user_name: typing.Optional[builtins.str] = None,
+                default_database_name: typing.Optional[builtins.str] = None,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                engine_version: typing.Optional[aws_cdk.aws_rds.IClusterEngine] = None,
+                instance_type: typing.Optional["InstanceTypeEnum"] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                rds_password: typing.Optional[builtins.str] = None,
+                storage_encrypted: typing.Optional[builtins.bool] = None,
+                time_zone: typing.Optional["MySQLtimeZone"] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument db_clusterp_pg", value=db_clusterp_pg, expected_type=type_hints["db_clusterp_pg"])
+            check_type(argname="argument db_user_name", value=db_user_name, expected_type=type_hints["db_user_name"])
+            check_type(argname="argument default_database_name", value=default_database_name, expected_type=type_hints["default_database_name"])
+            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
+            check_type(argname="argument engine_version", value=engine_version, expected_type=type_hints["engine_version"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
+            check_type(argname="argument rds_password", value=rds_password, expected_type=type_hints["rds_password"])
+            check_type(argname="argument storage_encrypted", value=storage_encrypted, expected_type=type_hints["storage_encrypted"])
+            check_type(argname="argument time_zone", value=time_zone, expected_type=type_hints["time_zone"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         self._values: typing.Dict[str, typing.Any] = {}
         if db_clusterp_pg is not None:
             self._values["db_clusterp_pg"] = db_clusterp_pg
@@ -628,6 +700,21 @@ class GlobalAuroraRDSSlaveInfra(
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                stack: typing.Optional[aws_cdk.Stack] = None,
+                storage_encrypted: typing.Optional[builtins.bool] = None,
+                subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GlobalAuroraRDSSlaveInfraProps(
             deletion_protection=deletion_protection,
             stack=stack,
@@ -638,7 +725,7 @@ class GlobalAuroraRDSSlaveInfra(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dbSubnetGroup")
     def db_subnet_group(self) -> aws_cdk.aws_rds.CfnDBSubnetGroup:
         '''(experimental) GlobalAuroraRDSSlaveInfra subnet group .
@@ -680,6 +767,22 @@ class GlobalAuroraRDSSlaveInfraProps:
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                *,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                stack: typing.Optional[aws_cdk.Stack] = None,
+                storage_encrypted: typing.Optional[builtins.bool] = None,
+                subnet_type: typing.Optional[aws_cdk.aws_ec2.SubnetType] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument deletion_protection", value=deletion_protection, expected_type=type_hints["deletion_protection"])
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
+            check_type(argname="argument storage_encrypted", value=storage_encrypted, expected_type=type_hints["storage_encrypted"])
+            check_type(argname="argument subnet_type", value=subnet_type, expected_type=type_hints["subnet_type"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         self._values: typing.Dict[str, typing.Any] = {}
         if deletion_protection is not None:
             self._values["deletion_protection"] = deletion_protection
@@ -1299,26 +1402,53 @@ class MySQLtimeZone(enum.Enum):
 @jsii.data_type(
     jsii_type="cdk-aurora-globaldatabase.RegionalOptions",
     jsii_struct_bases=[],
-    name_mapping={"region": "region", "db_subnet_group_name": "dbSubnetGroupName"},
+    name_mapping={
+        "region": "region",
+        "db_parameter_group": "dbParameterGroup",
+        "db_subnet_group_name": "dbSubnetGroupName",
+        "security_group_id": "securityGroupId",
+    },
 )
 class RegionalOptions:
     def __init__(
         self,
         *,
         region: builtins.str,
+        db_parameter_group: typing.Optional[builtins.str] = None,
         db_subnet_group_name: typing.Optional[builtins.str] = None,
+        security_group_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param region: 
+        :param db_parameter_group: 
         :param db_subnet_group_name: 
+        :param security_group_id: 
 
         :stability: experimental
         '''
+        if __debug__:
+            def stub(
+                *,
+                region: builtins.str,
+                db_parameter_group: typing.Optional[builtins.str] = None,
+                db_subnet_group_name: typing.Optional[builtins.str] = None,
+                security_group_id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument db_parameter_group", value=db_parameter_group, expected_type=type_hints["db_parameter_group"])
+            check_type(argname="argument db_subnet_group_name", value=db_subnet_group_name, expected_type=type_hints["db_subnet_group_name"])
+            check_type(argname="argument security_group_id", value=security_group_id, expected_type=type_hints["security_group_id"])
         self._values: typing.Dict[str, typing.Any] = {
             "region": region,
         }
+        if db_parameter_group is not None:
+            self._values["db_parameter_group"] = db_parameter_group
         if db_subnet_group_name is not None:
             self._values["db_subnet_group_name"] = db_subnet_group_name
+        if security_group_id is not None:
+            self._values["security_group_id"] = security_group_id
 
     @builtins.property
     def region(self) -> builtins.str:
@@ -1329,6 +1459,14 @@ class RegionalOptions:
         assert result is not None, "Required property 'region' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def db_parameter_group(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("db_parameter_group")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def db_subnet_group_name(self) -> typing.Optional[builtins.str]:
         '''
@@ -1337,6 +1475,14 @@ class RegionalOptions:
         result = self._values.get("db_subnet_group_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def security_group_id(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("security_group_id")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
